@@ -13,11 +13,11 @@ Net::JBoss::Management - Bindings for JBoss Management API
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
@@ -48,8 +48,8 @@ use Net::JBoss::Management;
  my $datasources        = $jboss->get_datasources();
  my $test               = $jboss->test_con_pool('ExampleDS');
  my $pool_stats         = $jboss->get_ds_pool_stats('java:jboss/datasources/jboss_Pool');
- my $enable_pool_stats  = $jboss->get_ds_pool_stats('java:jboss/datasources/jboss_Pool', 'true');
- my $disable_pool_stats = $jboss->get_ds_pool_stats('java:jboss/datasources/jboss_Pool', 'false');
+ my $enable_pool_stats  = $jboss->set_ds_pool_stats('java:jboss/datasources/jboss_Pool', 'true');
+ my $disable_pool_stats = $jboss->set_ds_pool_stats('java:jboss/datasources/jboss_Pool', 'false');
  my $min_pool_size      = $jboss->set_ds_pool_size('min', 'java:jboss/datasources/jboss_Pool', 20);
  my $max_pool_size      = $jboss->set_ds_pool_size('max', 'java:jboss/datasources/jboss_Pool', 50);
  my $jndi               = $jboss->get_jndi();
@@ -282,7 +282,15 @@ sub get_ds_pool_stats {
     $ds_name = url_encode_utf8($ds_name);
     $self->log->debug("encode : $ds_name");
     
-    $self->_set_resource_url(qq|/subsystem/datasources/data-source/$ds_name/statistics/pool/?operation=resource&recursive=true&include-runtime=true&json.pretty|);
+    if ($self->is_xa eq 'no')
+    {
+        $self->_set_resource_url(qq|/subsystem/datasources/data-source/$ds_name/statistics/pool/?operation=resource&recursive=true&include-runtime=true&json.pretty|);
+    }
+    elsif ($self->is_xa eq 'yes')
+    {
+        $self->_set_resource_url(qq|/subsystem/datasources/xa-data-source/$ds_name/statistics/pool/?operation=resource&recursive=true&include-runtime=true&json.pretty|);
+    }
+
     $self->log->debug($self->resource_url);
     
     $self->get_api_response();   
